@@ -17,6 +17,8 @@ __all__ = [
     "force_option",
     "debug_option",
     "log_level_option",
+    "flask_debug_option",
+    "gunicorn_timeout_option",
 ]
 
 LOG_FMT = "%(asctime)s %(levelname)-8s %(message)s"
@@ -59,9 +61,15 @@ workers_option = click.option(
 )
 force_option = click.option("-f", "--force", is_flag=True)
 debug_option = click.option("--debug", is_flag=True)
+flask_debug_option = click.option(
+    "--debug",
+    is_flag=True,
+    help="Run flask dev server in debug mode (when not using --with-gunicorn)",
+)
+gunicorn_timeout_option = click.option("--timeout", type=int, help="The timeout used for gunicorn")
 
 # sorted level names, by log-level
-_level_names = sorted(logging._nameToLevel, key=logging._nameToLevel.get)
+_level_names = sorted(logging._nameToLevel, key=logging._nameToLevel.get)  # type: ignore
 
 
 def log_level_option(default: Union[str, int] = logging.INFO):
@@ -71,5 +79,8 @@ def log_level_option(default: Union[str, int] = logging.INFO):
         default = logging.getLevelName(level=default)
 
     return click.option(
-        "-ll", "--log-level", type=click.Choice(choices=_level_names, case_sensitive=False), default=default
+        "-ll",
+        "--log-level",
+        type=click.Choice(choices=_level_names, case_sensitive=False),
+        default=default,
     )
