@@ -3,11 +3,12 @@
 """Utilities for web applications."""
 
 import importlib
-from typing import TYPE_CHECKING, Any, Mapping, NoReturn, Optional, Union
+import sys
+from typing import TYPE_CHECKING, Any, Callable, Mapping, Optional, Union
 
 import click
 
-from .options import verbose_option, with_gunicorn_option, workers_option
+from .options import flask_debug_option, gunicorn_timeout_option, verbose_option, with_gunicorn_option, workers_option
 
 if TYPE_CHECKING:
     import flask  # noqa
@@ -21,7 +22,7 @@ __all__ = [
 
 
 def make_web_command(
-    app: Union[str, "flask.Flask"],
+    app: Union[str, "flask.Flask", Callable[[], "flask.Flask"]],
     *,
     group: Optional[click.Group] = None,
     command_kwargs: Optional[Mapping[str, Any]] = None,
@@ -40,14 +41,54 @@ def make_web_command(
     @with_gunicorn_option
     @workers_option
     @verbose_option
-    @click.option("--debug", is_flag=True, help="Run flask dev server in debug mode (when not using --with-gunicorn)")
-    def web(host: str, port: str, with_gunicorn: bool, workers: int, debug: bool):
+    @gunicorn_timeout_option
+    @flask_debug_option
+    def web(
+        host: str,
+        port: str,
+        with_gunicorn: bool,
+        workers: int,
+        debug: bool,
+        timeout: Optional[int],
+    ):
         """Run the web application."""
+        import flask
+
         nonlocal app
         if isinstance(app, str):
-            package_name, class_name = app.split(":")
+            if app.count(":") != 1:
+                raise ValueError(
+                    "there should be exactly one colon in the string pointing to"
+                    " an app like modulename.submodulename:appname_in_module"
+                )
+            package_name, class_name = app.split(":", 1)
             package = importlib.import_module(package_name)
             app = getattr(package, class_name)
+            if isinstance(app, flask.Flask):
+                pass
+            elif callable(app):
+                app = app()
+            else:
+                raise TypeError(
+                    "when using a string path with more_click.make_web_command(),"
+                    " it's required that it points to either an instance of a Flask"
+                    " application or a 0-argument function that returns one."
+                )
+        elif isinstance(app, flask.Flask):
+            pass
+        elif callable(app):
+            app = app()
+        else:
+            raise TypeError(
+                "when using more_click.make_web_command(), the app argument should either"
+                " be an instance of a Flask app, a 0-argument function that returns a Flask app,"
+                " a string pointing to a Flask app in a python module, or a string pointing to a"
+                " 0-argument function that returns a Flask app"
+            )
+
+        if debug and with_gunicorn:
+            click.secho("can not use --debug and --with-gunicorn together")
+            return sys.exit(1)
 
         run_app(
             app=app,
@@ -56,6 +97,7 @@ def make_web_command(
             workers=workers,
             with_gunicorn=with_gunicorn,
             debug=debug,
+            timeout=timeout,
         )
 
     return web
@@ -67,8 +109,9 @@ def run_app(
     host: Optional[str] = None,
     port: Optional[str] = None,
     workers: Optional[int] = None,
+    timeout: Optional[int] = None,
     debug: bool = False,
-) -> NoReturn:
+):
     """Run the application."""
     if not with_gunicorn:
         app.run(host=host, port=port, debug=debug)
@@ -77,7 +120,13 @@ def run_app(
     elif debug:
         raise ValueError("can not use debug=True with with_gunicorn=True")
     else:
-        gunicorn_app = make_gunicorn_app(app, host, port, workers)
+        gunicorn_app = make_gunicorn_app(
+            app,
+            host=host,
+            port=port,
+            workers=workers,
+            timeout=timeout,
+        )
         gunicorn_app.run()
 
 
@@ -86,6 +135,7 @@ def make_gunicorn_app(
     host: str,
     port: str,
     workers: int,
+    timeout: Optional[int] = None,
     **kwargs,
 ) -> "gunicorn.app.base.BaseApplication":
     """Make a GUnicorn App."""
@@ -114,5 +164,7 @@ def make_gunicorn_app(
             "workers": workers,
         }
     )
+    if timeout is not None:
+        kwargs["timeout"] = timeout
 
     return StandaloneApplication(kwargs)
